@@ -7,7 +7,8 @@ from .controllers.create_apps import AppSetup
 
 # configuration defaults
 CONFIG = init_defaults('kluff')
-BASE_DIR = os.path.dirname(os.path.realpath(__file__))
+BASE_DIR, filename = os.path.split(os.path.abspath(__file__))
+# BASE_DIR = os.path.dirname(os.path.realpath(__file__))
 CONFIG['kluff']['base_dir'] = BASE_DIR
 CONFIG['kluff']['templates'] = os.path.join(BASE_DIR, 'templates')
 print('base',BASE_DIR)
